sshcmder

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 21, 2026 License: AGPL-3.0 Imports: 6 Imported by: 0

Documentation

Overview

Package sshcmder provides the ssh command for connecting to a running sandbox via SSH.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewSSHCmd

func NewSSHCmd(configDirFn func() string, verboseFn func() bool) *cobra.Command

NewSSHCmd creates the ssh command. verboseFn is called at runtime to check whether verbose output is enabled (resolved via viper).

Types

This section is empty.

Jump to